@@ -9,20 +9,22 @@ import (
 	"github.com/MixinNetwork/mixin/config"
 )
 
-// FIXME GLOBAL VARAIBLES
+// FIXME GLOBAL VARIABLES
 
 var (
+	inTest   bool
 	mutex    *sync.RWMutex
 	mockDiff time.Duration
 )
 
 func init() {
+	inTest = strings.Contains(config.BuildVersion, "BUILD_VERSION")
 	mutex = new(sync.RWMutex)
 	mockDiff = 0
 }
 
 func Reset() {
-	if !inTest() {
+	if !inTest {
 		panic(fmt.Errorf("clock reset not allowed in build version %s", config.BuildVersion))
 	}
 
@@ -32,7 +34,7 @@ func Reset() {
 }
 
 func MockDiff(at time.Duration) {
-	if !inTest() {
+	if !inTest {
 		panic(fmt.Errorf("clock mock not allowed in build version %s", config.BuildVersion))
 	}
 
@@ -42,7 +44,7 @@ func MockDiff(at time.Duration) {
 }
 
 func Now() time.Time {
-	if !inTest() {
+	if !inTest {
 		return time.Now()
 	}
 
@@ -50,7 +52,3 @@ func Now() time.Time {
 	defer mutex.RUnlock()
 	return time.Now().Add(mockDiff)
 }
-
-func inTest() bool {
-	return strings.Contains(config.BuildVersion, "BUILD_VERSION")
-}
