@@ -13,8 +13,8 @@ const (
 	graphPrefixDomainRemove = "DOMAINREMOVE"
 )
 
-func (s *BadgerStore) ReadDomains() []common.Domain {
-	domains := make([]common.Domain, 0)
+func (s *BadgerStore) ReadDomains() []*common.Domain {
+	domains := make([]*common.Domain, 0)
 	txn := s.snapshotsDB.NewTransaction(false)
 	defer txn.Discard()
 
@@ -25,16 +25,14 @@ func (s *BadgerStore) ReadDomains() []common.Domain {
 	for it.Seek(prefix); it.ValidForPrefix(prefix); it.Next() {
 		key := it.Item().KeyCopy(nil)
 		acc := domainAccountForState(key, graphPrefixDomainAccept)
-		domains = append(domains, common.Domain{Account: acc})
+		domains = append(domains, &common.Domain{Account: acc})
 	}
 	return domains
 }
 
 func writeDomainAccept(txn *badger.Txn, publicSpend crypto.Key, tx crypto.Hash, timestamp uint64) error {
 	key := graphDomainAcceptKey(publicSpend)
-	buf := make([]byte, 8)
-	binary.BigEndian.PutUint64(buf, timestamp)
-	val := append(tx[:], buf...)
+	val := binary.BigEndian.AppendUint64(tx[:], timestamp)
 	return txn.Set(key, val)
 }
 
